
using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;
using MindFusion.Scheduling;
using MindFusion.Scheduling.Compact;


namespace DragDrop
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class MainForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.PictureBox _item1;
		private System.Windows.Forms.PictureBox _item2;
		private System.Windows.Forms.PictureBox _item3;
		private MindFusion.Scheduling.Compact.Calendar _calendar;
		private System.Windows.Forms.Panel _panel;

		public MainForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			_calendar.Theme = ThemeType.LightBlue;

			_dragging = false;

			this._item1.MouseDown += new MouseEventHandler(this.OnItemMouseDown);
			this._item2.MouseDown += new MouseEventHandler(this.OnItemMouseDown);
			this._item3.MouseDown += new MouseEventHandler(this.OnItemMouseDown);
			this.MouseMove += new MouseEventHandler(this.OnMouseMove);
			this.MouseUp += new MouseEventHandler(this.OnMouseUp);

			_style1 = new Style();

			_style1.LineColor = Color.FromArgb(66, 166, 59);
			_style1.BorderColorLight = Color.FromArgb(66, 166, 59);
			_style1.BorderColorDark = Color.FromArgb(66, 166, 59);
			_style1.Brush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(176, 222, 156));
			_style1.HeaderTextColor = Color.FromArgb(9, 126, 0);

			_style2 = new Style();

			_style2.LineColor = Color.FromArgb(148, 64, 139);
			_style2.BorderColorLight = Color.FromArgb(148, 64, 139);
			_style2.BorderColorDark = Color.FromArgb(148, 64, 139);
			_style2.Brush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(223, 190, 219));
			_style2.HeaderTextColor = Color.FromArgb(148, 7, 134);

			// Mark schedule cells as custom drawn. This
			// would allow us to add visual indication to
			// the user, when he or she drags an item over the control
			_calendar.CustomDraw = CustomDrawElements.TimetableCell;
			_calendar.Draw += new CustomDraw(this._calendar_Draw);

			_pointedDate = DateTime.MinValue;
		}
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			base.Dispose( disposing );
		}
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this._panel = new System.Windows.Forms.Panel();
			this._item1 = new System.Windows.Forms.PictureBox();
			this._item2 = new System.Windows.Forms.PictureBox();
			this._item3 = new System.Windows.Forms.PictureBox();
			this._calendar = new MindFusion.Scheduling.Compact.Calendar();
			// 
			// _panel
			// 
			this._panel.Controls.Add(this._item1);
			this._panel.Controls.Add(this._item2);
			this._panel.Controls.Add(this._item3);
			this._panel.Location = new System.Drawing.Point(0, 232);
			this._panel.Size = new System.Drawing.Size(240, 40);
			// 
			// _item1
			// 
			this._item1.Image = ((System.Drawing.Image)(resources.GetObject("_item1.Image")));
			this._item1.Size = new System.Drawing.Size(40, 40);
			this._item1.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
			// 
			// _item2
			// 
			this._item2.Image = ((System.Drawing.Image)(resources.GetObject("_item2.Image")));
			this._item2.Location = new System.Drawing.Point(48, 0);
			this._item2.Size = new System.Drawing.Size(40, 40);
			this._item2.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
			// 
			// _item3
			// 
			this._item3.Image = ((System.Drawing.Image)(resources.GetObject("_item3.Image")));
			this._item3.Location = new System.Drawing.Point(96, 0);
			this._item3.Size = new System.Drawing.Size(40, 40);
			this._item3.SizeMode = System.Windows.Forms.PictureBoxSizeMode.StretchImage;
			// 
			// _calendar
			// 
			this._calendar.CurrentView = MindFusion.Scheduling.Compact.CalendarView.Timetable;
			this._calendar.Date = new System.DateTime(2005, 11, 25, 0, 0, 0, 0);
			this._calendar.EndDate = new System.DateTime(2005, 12, 25, 0, 0, 0, 0);
			this._calendar.Size = new System.Drawing.Size(240, 232);
			this._calendar.TimetableSettings.CellTime = System.TimeSpan.Parse("00:10:00");
			// 
			// MainForm
			// 
			this.Controls.Add(this._calendar);
			this.Controls.Add(this._panel);
			this.MinimizeBox = false;
			this.Text = "Drag & Drop Sample";

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>

		static void Main() 
		{
			Application.Run(new MainForm());
		}


		private void OnItemMouseDown(object sender, MouseEventArgs e)
		{
			if (e.Button == MouseButtons.Left)
			{
				_dragging = true;
				_draggedItem = sender;
				this.Capture = true;
			}
		}

		private void OnMouseMove(object sender, MouseEventArgs e)
		{
			if (_dragging)
			{
				Point pt = PointToScreen(new Point(e.X, e.Y));
				pt = _calendar.PointToClient(pt);

				DateTime pointedDate = _calendar.GetDateAt(pt);

				if (pointedDate != _pointedDate)
				{
					_pointedDate = pointedDate;

					// Repaint
					_calendar.Invalidate();
				}
			}
		}

		private void OnMouseUp(object sender, MouseEventArgs e)
		{
			if (_dragging)
			{
				if (_calendar.Bounds.Contains(e.X, e.Y))
				{
					// Create an item on the drop spot
					Point point = new Point(e.X, e.Y);

					point = PointToScreen(point);
					point = _calendar.PointToClient(point);

					DateTime date = _calendar.GetDateAt(point);
					if (date != DateTime.MinValue)
					{
						Form1 f = new Form1();

						if (f.ShowDialog() == DialogResult.OK)
						{
							int t = f.Choice;

							TimeSpan len = TimeSpan.Zero;
							if (t <= 5)
								len = TimeSpan.FromMinutes((t + 1) * 10);
							else if (t == 6)
								len = TimeSpan.FromHours(2);
							else if (t == 7)
								len = TimeSpan.FromHours(3);

							Appointment app = new Appointment();
							app.StartTime = date;
							app.EndTime = date + len;

							if (_draggedItem == _item1)
								app.HeaderText = "Meeting";
							else if (_draggedItem == _item2)
								app.HeaderText = "Event";
							else if (_draggedItem == _item3)
								app.HeaderText = "Appointment";

							app.DescriptionText = "This is a dropped item.";

							_calendar.Schedule.Items.Add(app);

							if (_draggedItem == _item2)
								app.Style = _style1;
							else if (_draggedItem == _item3)
								app.Style = _style2;
						}
					}
				}

				_dragging = false;
				_pointedDate = DateTime.MinValue;
				_draggedItem = null;
			}
		}

		private void DrawLines(MindFusion.Drawing.GraphicsEx graphics,
			Pen pen, Point[] lines)
		{
			for (int i = 0; i < lines.Length - 1; i++)
				graphics.DrawLine(pen, lines[i], lines[i + 1]);

			if (!lines[0].Equals(lines[lines.Length - 1]))
				graphics.DrawLine(pen, lines[lines.Length - 1], lines[0]);
		}

		private void _calendar_Draw(object sender, CustomDrawArgs e)
		{
			if (e.Element == CustomDrawElements.TimetableCell)
			{
				if (_pointedDate != DateTime.MinValue)
				{
					Brush brush = new SolidBrush(Color.LightSteelBlue);
					Brush blackBrush = new SolidBrush(Color.Black);
					Pen pen = new Pen(Color.SteelBlue);

					TimeSpan segment = _calendar.TimetableSettings.CellTime;

					DateTime cellStart = e.Date + e.StartTime;
					DateTime cellEnd = e.Date + e.EndTime;

					DateTime prevCellStart = cellStart - segment;
					DateTime prevCellEnd = cellEnd - segment;

					Rectangle bounds = e.Bounds;
					bounds.Width -= 1;
					bounds.Height -= 1;

					// Fill the cell
					if (cellStart <= _pointedDate && _pointedDate < cellEnd)
					{
						// It is the first cell
						e.Graphics.FillRectangle(brush, bounds);

						// Draw lines on the left, top and right
						bounds.Y += 1;
						bounds.Height -= 1;
						DrawLines(e.Graphics, pen,
							new Point[]
							{
								new Point(bounds.Left, bounds.Bottom),
								new Point(bounds.Left, bounds.Top),
								new Point(bounds.Right, bounds.Top),
								new Point(bounds.Right, bounds.Bottom)
							});

						// Draw the time interval
						string interval = cellStart.ToString("hh:mm tt");
						e.Graphics.DrawString(interval, Font, blackBrush,
							new Point(bounds.Left + 2, bounds.Top + 2));
					}
					if (prevCellStart <= _pointedDate && _pointedDate < prevCellEnd)
					{
						// It is the second cell
						e.Graphics.FillRectangle(brush, bounds);

						// Draw lines on the left, top and right
						bounds.Height -= 1;
						DrawLines(e.Graphics, pen,
							new Point[]
							{
								new Point(bounds.Left, bounds.Top),
								new Point(bounds.Left, bounds.Bottom),
								new Point(bounds.Right, bounds.Bottom),
								new Point(bounds.Right, bounds.Top)
							});

						// Draw an icon
//						Image image = _hidden.Image;
//						e.Graphics.DrawImage(image,
//							bounds.X + bounds.Width - image.Width - 4,
//							bounds.Y + bounds.Height / 2 - image.Height / 2);
					}

					pen.Dispose();
					blackBrush.Dispose();
					brush.Dispose();
				}
			}
		}


		private DateTime _pointedDate;
		private bool _dragging;
		private object _draggedItem;

		private Style _style1;
		private Style _style2;
	}
}
